"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CandidatesRawMapper = exports.CandidatesMongoMapper = void 0;
const aw_core_1 = require("@alien-worlds/aw-core");
const aw_storage_mongodb_1 = require("@alien-worlds/aw-storage-mongodb");
const aw_antelope_1 = require("@alien-worlds/aw-antelope");
const entities_1 = require("../../domain/entities");
class CandidatesMongoMapper extends aw_storage_mongodb_1.MongoMapper {
    constructor() {
        super();
        this.mappingFromEntity.set('candidateName', {
            key: 'candidate_name',
            mapper: (value) => value,
        });
        this.mappingFromEntity.set('requestedpay', {
            key: 'requestedpay',
            mapper: (value) => new aw_antelope_1.AssetMongoMapper().fromEntity(value),
        });
        this.mappingFromEntity.set('rank', {
            key: 'rank',
            mapper: (value) => value,
        });
        this.mappingFromEntity.set('gapFiller', {
            key: 'gap_filler',
            mapper: (value) => value,
        });
        this.mappingFromEntity.set('totalVotePower', {
            key: 'total_vote_power',
            mapper: (value) => value,
        });
        this.mappingFromEntity.set('isActive', {
            key: 'is_active',
            mapper: (value) => value,
        });
        this.mappingFromEntity.set('numberVoters', {
            key: 'number_voters',
            mapper: (value) => value,
        });
        this.mappingFromEntity.set('avgVoteTimeStamp', {
            key: 'avg_vote_time_stamp',
            mapper: (value) => value,
        });
        this.mappingFromEntity.set('runningWeightTime', {
            key: 'running_weight_time',
            mapper: (value) => value,
        });
    }
    toEntity(mongoModel) {
        const { candidate_name, requestedpay, rank, gap_filler, total_vote_power, is_active, number_voters, avg_vote_time_stamp, running_weight_time, _id, ...rest } = mongoModel;
        return entities_1.Candidates.create(candidate_name || '', requestedpay ? new aw_antelope_1.AssetMongoMapper().toEntity(requestedpay) : aw_antelope_1.Asset.getDefault(), rank || 0, gap_filler || 0, total_vote_power || 0, is_active || 0, number_voters || 0, avg_vote_time_stamp || new Date(0), running_weight_time || 0, _id instanceof aw_storage_mongodb_1.MongoDB.ObjectId ? _id.toString() : undefined, rest);
    }
}
exports.CandidatesMongoMapper = CandidatesMongoMapper;
class CandidatesRawMapper extends aw_core_1.MapperImpl {
    fromEntity(entity) {
        throw new Error('Method not implemented');
    }
    toEntity(rawModel) {
        const { candidate_name, requestedpay, rank, gap_filler, total_vote_power, is_active, number_voters, avg_vote_time_stamp, running_weight_time, ...rest } = rawModel;
        return entities_1.Candidates.create(candidate_name || '', requestedpay ? new aw_antelope_1.AssetRawMapper().toEntity(requestedpay) : aw_antelope_1.Asset.getDefault(), rank || 0, gap_filler || 0, total_vote_power || 0, is_active || 0, number_voters || 0, avg_vote_time_stamp || new Date(0), running_weight_time || 0, undefined, rest);
    }
}
exports.CandidatesRawMapper = CandidatesRawMapper;
